@@ -6,7 +6,8 @@ from stanza import Pipeline
 import logging
 
 logging.getLogger("stanza").setLevel(logging.WARNING)
-
+stanza.download('en', processors='tokenize,lemma,pos,ner')
+stanza.download('en', package='radiology')
 
 class RadEntityMatchExact(nn.Module):
     def __init__(self, **kwargs):
