@@ -18,11 +18,12 @@ REWARD_COMPLIANT = {
     "radentitynli": [RadEntityNLI, 1],
     "chexbert": [CheXbert, 1],
     "radgraph": [RadGraph, 1],
+    "bertscore": [BertScore, 1],
     # "MAUVE": [MauveScorer, 0],
 }
 
 
-def compute_scores(metrics, refs, hyps, split, seed, config, epoch, logger):
+def compute_scores(metrics, refs, hyps, split, seed, config, epoch, logger, dump=True):
     scores = dict()
     # If metric is None or empty list
     if metrics is None or not metrics:
@@ -34,19 +35,20 @@ def compute_scores(metrics, refs, hyps, split, seed, config, epoch, logger):
     assert len(refs) == len(hyps), 'refs and hyps must have same length : {} vs {}'.format(len(refs), len(hyps))
 
     # Dump
-    ckpt_dir = config.ckpt_dir
-    base = os.path.join(ckpt_dir, '{}_{}_{}'.format(split, seed, '{}'))
-    refs_file = base.format('refs.txt')
-    hyps_file = base.format('hyps.txt')
-    metrics_file = base.format('metrics.txt')
+    if dump:
+        ckpt_dir = config.ckpt_dir
+        base = os.path.join(ckpt_dir, '{}_{}_{}'.format(split, seed, '{}'))
+        refs_file = base.format('refs.txt')
+        hyps_file = base.format('hyps.txt')
+        metrics_file = base.format('metrics.txt')
 
-    with open(refs_file, 'w') as f:
-        f.write('\n'.join(map(str, refs)))
-        f.close()
+        with open(refs_file, 'w') as f:
+            f.write('\n'.join(map(str, refs)))
+            f.close()
 
-    with open(hyps_file, 'w') as f:
-        f.write('\n'.join(map(str, hyps)))
-        f.close()
+        with open(hyps_file, 'w') as f:
+            f.write('\n'.join(map(str, hyps)))
+            f.close()
 
     for metric in metrics:
         # metric_args = dict()
@@ -66,6 +68,8 @@ def compute_scores(metrics, refs, hyps, split, seed, config, epoch, logger):
             scores["METEOR"] = Meteor()(refs, hyps)[0]
         elif metric == 'CIDERD':
             scores["CIDERD"] = CiderD()(refs, hyps)[0]
+        elif metric == 'bertscore':
+            scores["bertscore"] = BertScore()(refs, hyps)[0]
         elif metric in ['ROUGE1', 'ROUGE2', 'ROUGEL']:
             scores[metric] = Rouge(rouges=[metric.lower()])(refs, hyps)[0]
         elif metric == 'MAUVE':
@@ -79,8 +83,9 @@ def compute_scores(metrics, refs, hyps, split, seed, config, epoch, logger):
             scores["auroc"] = roc_auc_score(refs, F.softmax(torch.from_numpy(hyps), dim=-1).numpy(), multi_class="ovr")
         elif metric == 'chexbert':
             accuracy, accuracy_per_sample, chexbert_all, chexbert_5 = CheXbert(
-                refs_filename=base.format('refs.chexbert.txt'),
-                hyps_filename=base.format('hyps.chexbert.txt'))(hyps, refs)
+                refs_filename=base.format('refs.chexbert.txt') if dump else None,
+                hyps_filename=base.format('hyps.chexbert.txt') if dump else None) \
+                (hyps, refs)
             scores["chexbert-5_micro avg_f1-score"] = chexbert_5["micro avg"]["f1-score"]
             scores["chexbert-all_micro avg_f1-score"] = chexbert_all["micro avg"]["f1-score"]
         elif metric == 'radentitymatchexact':
@@ -88,14 +93,20 @@ def compute_scores(metrics, refs, hyps, split, seed, config, epoch, logger):
         elif metric == 'radentitynli':
             scores["radentitynli"] = RadEntityNLI()(refs, hyps)[0]
         elif metric == 'radgraph':
-            scores["radgraph"] = RadGraph()(refs=refs, hyps=hyps)[0]
+            scores["radgraph_simple"], scores["radgraph_partial"], scores["radgraph_complete"] = \
+                RadGraph(reward_level="full")(refs=refs, hyps=hyps)[0]
         else:
             logger.warning("Metric not implemented: {}".format(metric))
 
-    with open(metrics_file, 'a+') as f:
-        f.write(json.dumps({
-            'split': split,
-            'epoch': epoch,
-            'scores': scores
-        }, indent=4, sort_keys=False))
+    if dump:
+        with open(metrics_file, 'a+') as f:
+            f.write(json.dumps({
+                'split': split,
+                'epoch': epoch,
+                'scores': scores
+            }, indent=4, sort_keys=False))
     return scores
+
+
+if __name__ == '__main__':
+    pass
