@@ -1,5 +1,7 @@
 import os
 import pydicom
+from pydicom.pixel_data_handlers.util import apply_voi_lut
+
 import numpy as np
 import json
 import PIL
@@ -58,7 +60,11 @@ def default_collate(batch):
 
 
 def read_images(root, image_path, split, file):
-    lines = load_file(os.path.join(root, split + '.' + file))
+    file_path = os.path.join(root, split + '.' + file)
+    if '.npy' in file_path:
+        return [[x] for x in np.load(file_path)]
+
+    lines = load_file(file_path)
     return [[os.path.join(image_path, image) for image in line.split(',')] for line in lines]
 
 
@@ -91,14 +97,14 @@ def get_transforms(split, resize, crop, custom_transform_train, custom_transform
                                  (0.229, 0.224, 0.225))])
     else:
         return transforms.Compose([
-            transforms.Resize((224, 224)),
+            transforms.Resize((crop, crop)),
             transforms.ToTensor(),
             transforms.Normalize((0.485, 0.456, 0.406),
                                  (0.229, 0.224, 0.225))])
 
 
 def open_image(image, ext):
-    if ext == '.jpg':
+    if ext == '.jpg' or ext == '.jpeg':
         return Image.open(image).convert('RGB')
 
     if ext == '.xrv':
@@ -115,11 +121,20 @@ def open_image(image, ext):
 
     if ext == '.dcm':
         ds = pydicom.dcmread(image)
-        img = ds.pixel_array
-        return Image.fromarray(np.uint8(img)).convert('RGB')
+        if 'WindowWidth' in ds:
+            img = apply_voi_lut(ds.pixel_array, ds).astype(float)
+        else:
+            img = ds.pixel_array.astype(float)
+        img = (np.maximum(img, 0) / img.max()) * 255.0
+        img = np.uint8(img)
+        return Image.fromarray(img).convert('RGB')
 
     if ext in ['.npy', '.npz']:
-        return torch.from_numpy(np.load(image))
+        if type(image) == str:
+            image = np.load(image)
+        if type(image) == np.ndarray:
+            image = torch.from_numpy(image)
+        return image
 
     # Special cases
     if ext in PAPER_EXT.keys():
@@ -128,8 +143,8 @@ def open_image(image, ext):
     raise NotImplementedError("Image extension {} not implemented".format(ext))
 
 
-def do_image(image, transform, ext):
-    opened_images = [open_image(im, ext) for im in image]
+def do_images(images, transform, ext):
+    opened_images = [open_image(im, ext) for im in images]
     transformed_images = [transform(im) for im in opened_images]
     return transformed_images
 
@@ -178,12 +193,22 @@ class ImageDataset(Dataset):
         return len(self.images or [])
 
     def __getitem__(self, index):
-        return {'image': do_image(self.images[index], self.transform, self.ext)}
+        return {'image': do_images(self.images[index], self.transform, self.ext)}
 
     def inference(self, image):
-        if not isinstance(image, list):
-            image = [image]
-        batch = [{'image': do_image(i, self.transform, self.ext)} for i in image]
+        if not isinstance(image, (list, str)):
+            raise TypeError("Input for image must be str or list")
+
+        if isinstance(image, str):
+            image = [[image]]
+
+        if isinstance(image, list):
+            for i, im in enumerate(image):
+                if isinstance(im, str):
+                    image[i] = [im]
+
+        # Image is a list of example, an example a list of images.
+        batch = [{'image': do_images(i, self.transform, self.ext)} for i in image]
         return self.get_collate_fn()(batch)
 
     def get_collate_fn(self):
