@@ -2,7 +2,10 @@ from vilmedic.models.mvqa.MVQA import MVQA
 
 from vilmedic.models.rrs.SumRNN import SumRNN
 from vilmedic.models.rrs.SumHugMulti import SumHugMulti
+# from vilmedic.models.rrs.RRS_obsolete import RRS
 from vilmedic.models.rrs.RRS import RRS
+from vilmedic.models.rrs.RRS_SCST import RRS_SCST
+from vilmedic.models.rrs.RRS_SCST import RRS_SCST
 from vilmedic.models.rrs.SumHugMono_SCST import SumHugMono_SCST
 
 from vilmedic.models.selfsup.clip.VAE import VAE
@@ -10,8 +13,8 @@ from vilmedic.models.selfsup.clip.DALLE import DALLE
 from vilmedic.models.selfsup.clip.CLIP import CLIP
 
 from vilmedic.models.rrg.RRG import RRG
+from vilmedic.models.rrg.RRG_EEG import RRG_EEG
 from vilmedic.models.rrg.RRG_PPO import RRG_PPO
-from vilmedic.models.rrg.RRG_PPO_x import RRG_PPO_x
 from vilmedic.models.rrg.RRG_SCST import RRG_SCST
 
 from vilmedic.models.selfsup.conVIRT import ConVIRT
